package main

import (
	"context"

	"go.opentelemetry.io/otel"
	semconv "go.opentelemetry.io/otel/semconv/v1.7.0"
	_ "modernc.org/sqlite"

	"github.com/uptrace/opentelemetry-go-extra/otelplay"
	"github.com/uptrace/opentelemetry-go-extra/otelsql"
)

func main() {
	ctx := context.Background()

	shutdown := otelplay.ConfigureOpentelemetry(ctx)
	defer shutdown()

	db, err := otelsql.Open("sqlite", "file::memory:?cache=shared",
		otelsql.WithAttributes(semconv.DBSystemSqlite),
		otelsql.WithDBName("mydb"))
	if err != nil {
		panic(err)
	}

	tracer := otel.Tracer("app_or_package_name")

	ctx, span := tracer.Start(ctx, "root")
	defer span.End()

	if err := db.PingContext(ctx); err != nil {
		panic(err)
	}

	var num int
	if err := db.QueryRowContext(ctx, "SELECT 42").Scan(&num); err != nil {
		panic(err)
	}

	otelplay.PrintTraceID(ctx)
}
